
# 概述
DevEco Testing Hypium （以下简称Hypium）是由华为终端有限公司（以下简称“我们”或“华为”）提供的UI自动化测试框架。
华为非常重视您的个人信息和隐私保护，我们将会按照法律要求和业界成熟的安全标准，为您的个人信息提供相应的安全保护措施。

## 1 我们如何收集和使用您的个人信息
我们将通过Hypium为您提供下述业务功能，在您使用相关业务功能的过程中，我们会处理下列提供功能所必需的信息，
以便履行我们的合同义务。 若您不提供相关信息，会影响到您使用本应用的相关功能。
运行hypium
在您首次运行Hypium时，我们将会自动生成匿名化的随机ID，用于标识单个用户，最终会用于统计用户量，同时不会读取您的任何隐私信息。
在您使用Hypium的过程中，我们会收集执行设备的操作系统平台和版本号，用于更好地提供和执行平台适配的测试服务。
测试鸿蒙设备
当您使用Hypium测试鸿蒙设备上的应用时，我们会收集被测设备的型号以及鸿蒙系统版本、被测应用的名称或包名、
Hypium特性功能的触发时间和使用次数， 用于分析Hypium各功能在不同平台上的使用情况，从而针对性地优化我们的产品，
更好地为客户提供服务。

## 2 对未成年人的保护
我们非常重视对未成年人个人信息的保护，华为将严格按照国家法律法规要求在未成年人使用服务时提供相应的保护。
如果您是未成年人，需要您的父母或其他监护人同意您使用本应用并同意相关应用的服务条款。父母或其他监护人也应
采取适当的预防措施来保护未成年人，包括监督其对本应用的使用。如您是儿童，请立即停止使用本应用。

## 3 管理您的个人信息
华为非常尊重您对个人信息的关注，并为您提供了数据主体权利及选择。

### 3.1 信息访问
如您希望获取您的个人信息及其副本，可通过本声明中“如何联系我们”章节中所述方式与我们取得联系，并获取您的个人信息及其副本。

### 3.2 信息更正

当您需要更新您的个人信息，或发现我们处理您的个人信息有误时，您有权请求更正或更新。您可以通过本声明中“如何联系我们”
章节中所述方式与我们取得联系， 并修改您的个人信息。 

### 3.3 信息删除
您随时可以通过本声明中“如何联系我们”章节中所述方式与我们取得联系，并要求我们删除您的个人信息。

### 3.4 停用服务
您可以在项目根目录运行 `python -m hypium telemetry disable` 来停止Hypium处理您的个人信息。
您可以在项目根目录运行 `python -m hypium telemetry enable` 来恢复Hypium对您个人信息的处理。
您可以在项目根目录运行 `python -m hypium telemetry status` 来查看Hypium个人信息处理状态。

## 4 数据存储地点及期限

### 4.1 存储地点
上述信息将会传输并保存至中华人民共和国境内的服务器。

### 4.2 存储期限
我们仅在实现本声明所述目的所必需的时间内保留您的个人信息，并在超出下述保留时间后删除或匿名化处理您的个人信息，除非法律法规另有要求。
工具自身的测试数据及其备份数据将保存5年，目的是确保您的数据安全。
此外，当我们的产品或服务发生停止运营的情形时，我们将以推送通知、公告等形式通知您，并在合理的期限内删除您的个人信息或进行匿名化处理。

## 5 如何联系我们
我们指定了个人信息保护负责人，您可以通过链接https://consumer.huawei.com/cn/legal/privacy-questions
联系个人信息保护负责人。您也可以通过访问隐私问题页面与我们取得联系，我们会尽快回复。
如果您对我们的回复不满意，特别是当我们的个人信息处理行为损害了您的合法权益时，您还可以通过向有管辖权的人民法院提起诉讼、
向行业自律协会或政府相关管理机构投诉等外部途径进行解决。您也可以向我们了解可能适用的相关投诉途径的信息。

华为将始终遵照我们的隐私政策来收集和使用您的信息。有关我们的隐私政策，可参阅《华为消费者业务隐私声明》。

